/*
 ============================================================================
 Name		 : Construction.cpp
 Copyright   : Symbian Academy, 2007
 Description : Exercise: Two-Phase Construction and Object Destruction
 ============================================================================
 */

//  Include Files  

#include <e32base.h>
#include <e32std.h>
#include <e32cons.h>			// Console

// Function prototype (C-style).
LOCAL_C void MainL();

//  Global Variables
LOCAL_D CConsoleBase* console;
// write all messages to this

// ------------------------------------------------------------------
// Definition of the CShopEntry class
// ------------------------------------------------------------------

class CShopEntry
	{
public:
	// Constructors & Destructors

private:
	// Private construction code

public:
	// Public functions
	/** Print the entry to the global console. */
	void PrintEntry();

private:
	// Private instance variables
	/** Name of the shop item. */
	RBuf iName;
	/** Price of the shop item. */
	TInt iPrice;
	};

// ------------------------------------------------------------------
// CShopEntry implementation
// ------------------------------------------------------------------

void CShopEntry::PrintEntry()
	{
	_LIT(KShopEntry, "Item: %S, Price: %d\n");
	console->Printf (KShopEntry, &iName, iPrice);
	}

// ------------------------------------------------------------------
// Main Application
// ------------------------------------------------------------------
GLDEF_C TInt E32Main()
	{
	// Create cleanup stack
	CTrapCleanup* cleanup = CTrapCleanup::New ();

	// Create output console
	_LIT(KTextConsoleTitle, "Console - Construction");
	TRAPD(createError, console = Console::NewL(KTextConsoleTitle, TSize(KConsFullScreen,KConsFullScreen)))
	;
	if ( createError)
		return createError;

	// Run application code inside TRAP harness
	__UHEAP_MARK;

	TRAPD(mainError, MainL())
	;
	_LIT(KTextFailed, "MainL() failed, leave code = %d\n");
	if ( mainError)
		{
		console->Printf (KTextFailed, mainError);
		}

	// Wait for the space key before exiting.
	// Generally better than accepting any key to prevent immediate shutdown
	// if a key has still been in the queue when the app. started.
	_LIT(KTextPressSpace, "\n[Press space to exit]\n");
	console->Printf (KTextPressSpace);
	while (console->Getch ()!= EKeySpace)
		{
		}

	// Check the state of the heap memory - if the same amount of memory
	// is available as before MainL() was executed, everything's fine.
	// Otherwise, a panic will be raised, which would result in a graphical
	// error dialog in an UI framework, but exits the application when
	// using the console mode.
	__UHEAP_MARKEND;

	// If the program passed the __UHEAP_MARKEND-macro, no memory
	// leaks were detected
	_LIT(KTextMemoryLeak, "\nNo memory leaks detected! [Press space]\n");
	console->Printf (KTextMemoryLeak);
	while (console->Getch ()!= EKeySpace)
		{
		}

	// Cleanup
	delete console;
	delete cleanup;
	return KErrNone;
	}

LOCAL_C void MainL()
	{
	// ------------------------------------------------------------------
	// Test code
	// ------------------------------------------------------------------
	_LIT(KEntry1, "Smartphone");
	_LIT(KEntry2, "Outdoor phone");
	_LIT(KEntry3, "Mid-level phone");

	// Write your test code here...
	
	
	
	}

